OntoPortalClient
================

.. currentmodule:: ontoportal_client.api

.. autoclass:: OntoPortalClient
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~OntoPortalClient.get_json
      ~OntoPortalClient.get_ontologies
      ~OntoPortalClient.get_response

   .. rubric:: Methods Documentation

   .. automethod:: get_json
   .. automethod:: get_ontologies
   .. automethod:: get_response
